@@ -14,6 +14,7 @@ from ExifTags import TAGS
 
 from optparse import make_option
 from django.core.management.base import BaseCommand, CommandError
+from django.template import Context, Template
 from django.conf import settings as conf
 import rgallery.models as mymodels
 from datetime import datetime
@@ -227,9 +228,13 @@ class Command(BaseCommand):
         print "[***] Total: %s" % total
 
         print "[***] Haciendo thumbs (200x200 y 750x750) de las que no tienen todavía"
+        conf.THUMBNAIL_DEBUG = True
         allphotos = mymodels.Photo.objects.all()
         for i,p in enumerate(allphotos):
             print "%s - %s" % (i, p)
+            c = Context({'image': p})
+            t = Template('{% load thumbnail %}{% thumbnail image "200x200" crop="top" as img %}{{ img.url }}{% endthumbnail %}')
+            t.render(c)
             im = get_thumbnail(p, "200x200")
             if p.image.width > 750 and p.image.height > 750:
                 im = get_thumbnail(p, "750x750")
