@@ -53,7 +53,7 @@ class Photo(models.Model):
     capture_date = models.DateTimeField(_(u'Photo date'))
     folder = models.ForeignKey(Folder, related_name='photo', null=True,
                                blank=True, verbose_name=_(u'Folder'))
-    tags = TaggableManager()
+    tags = TaggableManager(blank=True)
     status =  models.BooleanField(_(u'Status'), default=True)
 
     def __unicode__(self):
