@@ -2,33 +2,22 @@
 
 import os
 import json
-import Image
 import zipfile
 import urllib2
 from StringIO import StringIO
-from datetime import datetime
 
-from django.shortcuts import get_object_or_404, render_to_response
+from django.shortcuts import get_object_or_404
 from django.template.loader import render_to_string
-from django.template import RequestContext
-from django.contrib.auth.decorators import login_required
 from django.http import HttpResponse, HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
-from django.core.urlresolvers import reverse_lazy
-from django.shortcuts import redirect
-from django.contrib.sites.models import Site
-from django.contrib import messages
 import models as mymodels
-import forms as myforms
 
-from sorl.thumbnail import get_thumbnail
 from braces.views import LoginRequiredMixin, SuperuserRequiredMixin
 from taggit.models import Tag
 
 from django.conf import settings as conf
 
-from django.views.generic import DetailView, ListView, CreateView
-from django.views.generic.edit import ProcessFormView
+from django.views.generic import ListView, CreateView
 
 from engine import expire_view_cache
 from management.commands.utils import *
@@ -50,7 +39,7 @@ class Photos(TagMixin, ListView):
 
     template_name = "rgallery/photos.html"
     context_object_name = "photos"
-    paginate_by = 3
+    paginate_by = 150
 
     def get_queryset(self):
         if self.request.user.is_superuser:
@@ -94,7 +83,7 @@ class PhotosTag(ListView):
     template_name = "rgallery/photos.html"
     model = mymodels.Photo
     context_object_name = "photos"
-    paginate_by = 100
+    paginate_by = 150
 
     def get_queryset(self):
         if self.request.user.is_superuser:
@@ -103,6 +92,14 @@ class PhotosTag(ListView):
             return mymodels.Photo.objects.filter(status=1,
                 tags__slug=self.kwargs.get('slug', None)).order_by('-capture_date')
 
+    def get_context_data(self, **kwargs):
+        context = super(PhotosTag, self).get_context_data(**kwargs)
+
+        context.update({
+            'tag': self.kwargs.get('slug', None),
+        })
+        return context
+
 
 class PhotoAddTag(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
 
@@ -127,7 +124,9 @@ class PhotoAddTag(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                                 photo.tags.add(tag)
                     photo.save()
                     key = 'html-%s' % photo.pk
-                    response_data[key] = render_to_string('rgallery/_listags.html', {'record': photo.tags.all()})
+                    response_data[key] = render_to_string(
+                        'rgallery/_listags.html',
+                        {'record': photo.tags.all()})
                 response_data['multiple'] = 1
                 response_data['pk'] = pk
             else:
@@ -143,10 +142,12 @@ class PhotoAddTag(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                             photo.tags.add(tag)
                 photo.save()
                 response_data['multiple'] = 0
-                response_data['html'] = render_to_string('rgallery/_listags.html',
-                                        {'record': photo.tags.all()})
+                response_data['html'] = render_to_string(
+                    'rgallery/_listags.html',
+                    {'record': photo.tags.all()})
             expire_view_cache("app_gallery-gallery")
-            return HttpResponse(json.dumps(response_data), content_type="application/json")
+            return HttpResponse(json.dumps(response_data),
+                                content_type="application/json")
 
 
 class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
@@ -158,23 +159,25 @@ class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
     def form_valid(self, form):
         self.object = form.save(commit=False)
 
-        backend = __import__('rgallery.management.commands.backend_form', fromlist='*')
+        backend = __import__('rgallery.management.commands.backend_form',
+                             fromlist='*')
 
         # Set dirs (src, dest)
         srcdir, photodestdir, videodestdir = backend.set_dirs(form.files['file'])
 
-        img_duped, img_total, vid_duped, vid_total, total = mediasync(form.files['file'],
-                                                                      srcdir,
-                                                                      photodestdir,
-                                                                      videodestdir,
-                                                                      conf.RGALLLERY_THUMBS,
-                                                                      backend,
-                                                                      False,
-                                                                      0,
-                                                                      0,
-                                                                      0,
-                                                                      0,
-                                                                      0)
+        img_duped, img_total, vid_duped, vid_total, total = mediasync(
+            form.files['file'],
+            srcdir,
+            photodestdir,
+            videodestdir,
+            conf.RGALLLERY_THUMBS,
+            backend,
+            False,
+            0,
+            0,
+            0,
+            0,
+            0)
 
         expire_view_cache("app_gallery-gallery")
         return HttpResponseRedirect(self.get_success_url())
@@ -203,7 +206,8 @@ class PhotoDelete(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                 response_data['pk'] = pk
                 response_data['multiple'] = 0
             expire_view_cache("app_gallery-gallery")
-            return HttpResponse(json.dumps(response_data), content_type="application/json")
+            return HttpResponse(json.dumps(response_data),
+                                content_type="application/json")
 
 
 class PhotoDownload(LoginRequiredMixin, ListView):
@@ -224,7 +228,8 @@ class PhotoDownload(LoginRequiredMixin, ListView):
             fdir, fname = os.path.split(photo.image.path)
             zf.write(photo.image.path, fname)
         zf.close()
-        resp = HttpResponse(s.getvalue(), mimetype = "application/x-zip-compressed")
+        resp = HttpResponse(s.getvalue(),
+                            mimetype="application/x-zip-compressed")
         resp['Content-Disposition'] = 'attachment; filename=photos.zip'
         return resp
 
@@ -260,7 +265,8 @@ class PhotoChangeStatus(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                 response_data['status'] = photo.status
                 response_data['multiple'] = 0
             expire_view_cache("app_gallery-gallery")
-            return HttpResponse(json.dumps(response_data), content_type="application/json")
+            return HttpResponse(json.dumps(response_data),
+                                content_type="application/json")
 
 
 class PhotoGetVideo(LoginRequiredMixin, ListView):
@@ -273,14 +279,14 @@ class PhotoGetVideo(LoginRequiredMixin, ListView):
             photo = get_object_or_404(mymodels.Photo, pk=pk)
             rendered = render_to_string('rgallery/_video.html',
                                         {'video': photo.video})
-        return HttpResponse(rendered);
+        return HttpResponse(rendered)
 
 
 class Videos(ListView):
 
     template_name = "rgallery/videos.html"
     context_object_name = "videos"
-    paginate_by = 6
+    paginate_by = 150
 
     def get_queryset(self):
         vid = mymodels.Video.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
